"{ Package: 'stx:goodies/metacello/stx' }"

MetacelloAbstractPackageSpec subclass:#MetacelloStXPackageSpec
	instanceVariableNames:'repository preLoadDoIt postLoadDoIt'
	classVariableNames:''
	poolDictionaries:''
	category:'Metacello-St/X-Specs'
!

Collection subclass:#Prerequisites
	instanceVariableNames:'packageSpec suppressions additions'
	classVariableNames:''
	poolDictionaries:''
	privateIn:MetacelloStXPackageSpec
!


!MetacelloStXPackageSpec methodsFor:'printing & storing'!

configMethodOn: aStream indent: indent

     aStream 
        tab: indent; nextPutAll: 'spec '; nextPutAll: 'name: ', self name storeString; nextPut: $.; cr.

    "Created: / 03-10-2012 / 00:06:00 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!MetacelloStXPackageSpec methodsFor:'querying'!

requires

    requires == nil ifTrue: [ requires := Prerequisites for: self ].
    ^requires

    "Created: / 19-09-2012 / 02:35:21 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!MetacelloStXPackageSpec methodsFor:'visiting'!

projectDo: projectBlock packageDo: packageBlock groupDo: groupBlock
    packageBlock value: self

    "Created: / 03-10-2012 / 22:58:14 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!MetacelloStXPackageSpec::Prerequisites class methodsFor:'instance creation'!

for: spec
    ^self new initializeFor: spec

    "Created: / 05-09-2012 / 19:49:34 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!MetacelloStXPackageSpec::Prerequisites methodsFor:'adding & removing'!

add:anObject
    "add the argument, anObject to the receiver.
     If the receiver is ordered, the position of the new element is undefined
     (i.e. don't depend on where it will be put).
     An error is raised here - it is to be implemented by a concrete subclass."

    ^ self shouldImplement
!

addFirst:anObject
    "add the argument, anObject to the receiver.
     If the receiver is ordered, the new element will be added at the beginning.
     An error is raised here - it is to be implemented by a concrete subclass."

    ^ self shouldImplement
!

remove:anObject ifAbsent:exceptionBlock
    "search for the first element, which is equal to anObject;
     if found, remove and return it.
     If not found, return the the value of the exceptionBlock.
     Uses equality compare (=) to search for the occurrence.
     An error is raised here - it is to be implemented by a concrete subclass."

    ^ self shouldImplement
!

removeIdentical:anObject ifAbsent:exceptionBlock
    "search for the first element, which is identical to anObject;
     if found, remove and return it.
     If not found, return the the value of the exceptionBlock.
     Uses identity compare (==) to search for the occurrence.
     An error is raised here - it is to be implemented by a concrete subclass."

    ^ self shouldImplement
!

removeLast
    "remove the last element from the receiver.
     Return the removed element.
     An error is raised here - it is to be implemented by a concrete subclass."

    ^ self shouldImplement
! !

!MetacelloStXPackageSpec::Prerequisites methodsFor:'enumerating'!

do:aBlock
    "evaluate the argument, aBlock for each element"

    | def |

    def := ProjectDefinition definitionClassForPackage: packageSpec name.
    def preRequisites do:[:each|
        aBlock value: each
    ]

    "Modified: / 05-09-2012 / 19:53:08 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

reverseDo:aBlock
    "evaluate the argument, aBlock for each element in reverse order."

    ^ self do: aBlock

    "Modified: / 05-09-2012 / 19:51:24 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!MetacelloStXPackageSpec::Prerequisites methodsFor:'growing'!

grow:howBig
    "change the receivers size"

    ^ self shouldImplement
! !

!MetacelloStXPackageSpec::Prerequisites methodsFor:'initialization'!

initializeFor: aMetacelloStXPackageSpec
    packageSpec := aMetacelloStXPackageSpec

    "Created: / 05-09-2012 / 19:48:48 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!MetacelloStXPackageSpec class methodsFor:'documentation'!

version_SVN
    ^ '$Id::                                                                                                                        $'
! !
